package com.qmth.boot.core.ai.client;

import com.qmth.boot.core.ai.config.DocApiConfiguration;
import com.qmth.boot.core.ai.model.AiConstants;
import com.qmth.boot.core.ai.model.doc.ParseDocTask;
import com.qmth.boot.core.ai.model.doc.ParseDocTaskResult;
import com.qmth.boot.core.retrofit.annotatioin.RetrofitClient;
import com.qmth.boot.core.retrofit.utils.SignatureInfo;
import okhttp3.MultipartBody;
import retrofit2.http.*;

/**
 * 文档解析应用服务接口
 */
@RetrofitClient(configuration = DocApiConfiguration.class)
public interface DocApiClient {

    /**
     * 文档解析任务
     *
     * @param baseUrl   接口前缀地址，默认取配置文件的值（选填）
     * @param signature 使用机构AK构造Secret类型签名
     * @param file      待解析文件（如：pdf、word等）
     * @return
     */
    @Multipart
    @POST(AiConstants.DOC_PARSE_TASK_PATH)
    ParseDocTask parseDocTask(@Header(AiConstants.BASE_URL) String baseUrl, @Tag SignatureInfo signature,
                              @Part MultipartBody.Part file);

    /**
     * 文档解析任务结果查询
     *
     * @param baseUrl   接口前缀地址，默认取配置文件的值（选填）
     * @param signature 使用机构AK构造Secret类型签名
     * @param taskId    文档解析任务ID
     * @return
     */
    @POST(AiConstants.DOC_PARSE_TASK_QUERY_PATH)
    ParseDocTaskResult parseDocTaskQuery(@Header(AiConstants.BASE_URL) String baseUrl, @Tag SignatureInfo signature,
                                         @Query("taskId") String taskId);

}
